@@ -1,7 +1,6 @@
 """File translation command"""
 
 import logging
-import warnings
 
 import click
 from cligj import format_opt
@@ -13,9 +12,6 @@ import rasterio
 from rasterio.coords import disjoint_bounds
 
 
-warnings.simplefilter('default')
-
-
 # Clip command
 @click.command(short_help='Clip a raster to given bounds.')
 @click.argument(
