@@ -16,3 +16,8 @@ def test_resolve_files_inout__inout_files():
 def test_resolve_files_inout__inout_files_output_o():
     assert helpers.resolve_inout(
         files=('a', 'b', 'c'), output='out') == ('out', ['a', 'b', 'c'])
+
+
+def test_to_lower():
+    
+    assert helpers.to_lower(None, None, 'EPSG:3857') == 'epsg:3857'
\ No newline at end of file
