@@ -148,6 +148,26 @@ def test_write_crs_transform(tmpdir):
     # (precision varies slightly by platform)
     assert re.search("Pixel Size = \(300.03792\d+,-300.04178\d+\)", info)
 
+def test_write_crs_transform_affine(tmpdir):
+    name = str(tmpdir.join("test_write_crs_transform.tif"))
+    a = numpy.ones((100, 100), dtype=rasterio.ubyte) * 127
+    transform = [101985.0, 300.0379266750948, 0.0,
+                       2826915.0, 0.0, -300.041782729805]
+    with rasterio.open(
+            name, 'w', 
+            driver='GTiff', width=100, height=100, count=1,
+            crs={'units': 'm', 'no_defs': True, 'ellps': 'WGS84', 
+                 'proj': 'utm', 'zone': 18},
+            affine=transform,
+            dtype=rasterio.ubyte) as s:
+        s.write_band(1, a)
+    assert s.crs == {'init': 'epsg:32618'}
+    info = subprocess.check_output(["gdalinfo", name]).decode('utf-8')
+    assert 'PROJCS["UTM Zone 18, Northern Hemisphere",' in info
+    # make sure that pixel size is nearly the same as transform
+    # (precision varies slightly by platform)
+    assert re.search("Pixel Size = \(300.03792\d+,-300.04178\d+\)", info)
+
 def test_write_crs_transform_2(tmpdir):
     """Using 'EPSG:32618' as CRS."""
     name = str(tmpdir.join("test_write_crs_transform.tif"))
